@@ -1,9 +1,7 @@
-from __future__ import print_function, absolute_import
-
 import numpy as np
 
-from .. import drizzle
-from .. import cdrizzle
+from drizzle import drizzle
+from drizzle import cdrizzle
 
 def test_cdrizzle():
     """
@@ -24,6 +22,3 @@ def test_cdrizzle():
     cdrizzle.test_cdrizzle(data, weights, pixmap,
                            output_data, output_counts,
                            output_context)
-
-if __name__ == "__main__":
-    test_cdrizzle()
