@@ -1,5 +1,3 @@
-from __future__ import division, print_function, unicode_literals, absolute_import
-
 import sys
 import math
 import os
@@ -14,6 +12,8 @@ import numpy.testing as npt
 from astropy import wcs
 from astropy.io import fits
 
+from drizzle import drizzle
+
 TEST_DIR = os.path.abspath(os.path.dirname(__file__))
 DATA_DIR = os.path.join(TEST_DIR, 'data')
 OUTPUT_DIR = os.environ.get('DRIZZLE_TEST_OUTPUT_DIR', tempfile.mkdtemp())
@@ -24,8 +24,6 @@ def output_dir():
     if 'DRIZZLE_TEST_OUTPUT_DIR' not in os.environ:
         shutil.rmtree(OUTPUT_DIR)
 
-from .. import drizzle
-
 ok = False
 
 def bound_image(image):
@@ -38,7 +36,7 @@ def bound_image(image):
     xmin = coords[1].min()
     xmax = coords[1].max()
     return (ymin, ymax, xmin, xmax)
-    
+
 def centroid(image, size, center):
     """
     Compute the centroid of a rectangular area
@@ -47,7 +45,7 @@ def centroid(image, size, center):
     yhi = min(ylo + size, image.shape[0])
     xlo = int(center[1] - size / 2)
     xhi = min(xlo + size, image.shape[1])
-    
+
     center = [0.0, 0.0, 0.0]
     for y in range(ylo, yhi):
         for x in range(xlo, xhi):
@@ -59,7 +57,7 @@ def centroid(image, size, center):
 
     center[0] /= center[2]
     center[1] /= center[2]
-    return center        
+    return center
 
 def centroid_close(list_of_centroids, size, point):
     """
@@ -86,14 +84,14 @@ def centroid_distances(image1, image2, amp, size):
         if center1 is None: continue
 
         disty = center2[0] - center1[0]
-        distx = center2[1] - center1[1] 
+        distx = center2[1] - center1[1]
         dist = math.sqrt(disty * disty + distx * distx)
         dflux = abs(center2[2] - center1[2])
         distances.append([dist, dflux, center1, center2])
 
     distances.sort(key=centroid_compare)
     return distances
-    
+
 def centroid_list(image, amp, size):
     """
     Find the next centroid
@@ -104,7 +102,7 @@ def centroid_list(image, amp, size):
         if not centroid_close(list_of_centroids, size, point):
             center = centroid(image, size, point)
             list_of_centroids.append(center)
-                
+
     return list_of_centroids
 
 def centroid_statistics(title, fname, image1, image2, amp, size):
@@ -114,13 +112,13 @@ def centroid_statistics(title, fname, image1, image2, amp, size):
     stats = ("minimum", "median", "maximum")
     images = (None, None, image1, image2)
     im_type = ("", "", "test", "reference")
-    
+
     diff = []
     distances = centroid_distances(image1, image2, amp, size)
     indexes = (0, int(len(distances)/2), len(distances)-1)
     fd = open(fname, 'w')
     fd.write("*** %s ***\n" % title)
-    
+
     if len(distances) == 0:
         diff = [0.0, 0.0, 0.0]
         fd.write("No matches!!\n")
@@ -130,7 +128,7 @@ def centroid_statistics(title, fname, image1, image2, amp, size):
 
         fd.write("1 match\n")
         fd.write("distance = %f flux difference = %f\n" % (distances[0][0], distances[0][1]))
-        
+
         for j in range(2, 4):
             ylo = int(distances[0][j][0]) - 1
             yhi = int(distances[0][j][0]) + 2
@@ -140,7 +138,7 @@ def centroid_statistics(title, fname, image1, image2, amp, size):
             fd.write("\n%s image centroid = (%f,%f) image flux = %f\n" %
                      (im_type[j], distances[0][j][0], distances[0][j][1], distances[0][j][2]))
             fd.write(str(subimage) + "\n")
-              
+
     else:
         fd.write("%d matches\n" % len(distances))
 
@@ -168,21 +166,21 @@ def make_point_image(input_image, point, value):
     """
     output_image = np.zeros(input_image.shape, dtype=input_image.dtype)
     output_image[point] = value
-    return output_image   
+    return output_image
 
 def make_grid_image(input_image, spacing, value):
     """
     Create an image with points on a grid set
     """
     output_image = np.zeros(input_image.shape, dtype=input_image.dtype)
-    
+
     shape = output_image.shape
     half_space = int(spacing/2)
     for y in range(half_space, shape[0], spacing):
         for x in range(half_space, shape[1], spacing):
             output_image[y,x] = value
 
-    return output_image   
+    return output_image
 
 def print_wcs(title, wcs):
     """
@@ -190,8 +188,7 @@ def print_wcs(title, wcs):
     """
     print("=== %s ===" % title)
     print(wcs.to_header_string())
-    
-    
+
 def read_image(filename):
     """
     Read the image from a fits file
@@ -212,7 +209,7 @@ def read_wcs(filename):
     the_wcs = wcs.WCS(hdu[1].header)
     hdu.close()
     return the_wcs
-    
+
 def test_square_with_point():
     """
     Test do_driz square kernel with point
@@ -221,7 +218,7 @@ def test_square_with_point():
     output = os.path.join(OUTPUT_DIR, 'output_square_point.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_square_point.txt')
     output_template = os.path.join(DATA_DIR, 'reference_square_point.fits')
-    
+
     insci = read_image(input_file)
     inwcs = read_wcs(input_file)
     insci = make_point_image(insci, (500, 200), 100.0)
@@ -230,7 +227,7 @@ def test_square_with_point():
 
     driz = drizzle.Drizzle(outwcs=output_wcs, wt_scl="")
     driz.add_image(insci, inwcs, inwht=inwht)
-    
+
     if ok:
         driz.write(output_template)
     else:
@@ -251,7 +248,7 @@ def test_square_with_grid():
     output = os.path.join(OUTPUT_DIR, 'output_square_grid.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_square_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_square_grid.fits')
-    
+
     insci = read_image(input_file)
     inwcs = read_wcs(input_file)
     insci = make_grid_image(insci, 64, 100.0)
@@ -260,13 +257,13 @@ def test_square_with_grid():
 
     driz = drizzle.Drizzle(outwcs=output_wcs, wt_scl="")
     driz.add_image(insci, inwcs, inwht=inwht)
-    
+
     if ok:
         driz.write(output_template)
     else:
         driz.write(output)
         template_data = read_image(output_template)
-        
+
         (min_diff, med_diff, max_diff) = centroid_statistics("square with grid", output_difference,
                                                                   driz.outsci, template_data, 20.0, 8)
 
@@ -281,7 +278,7 @@ def test_turbo_with_grid():
     output = os.path.join(OUTPUT_DIR, 'output_turbo_grid.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_turbo_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_turbo_grid.fits')
-    
+
     insci = read_image(input_file)
     inwcs = read_wcs(input_file)
     insci = make_grid_image(insci, 64, 100.0)
@@ -290,13 +287,13 @@ def test_turbo_with_grid():
 
     driz = drizzle.Drizzle(outwcs=output_wcs, wt_scl="", kernel='turbo')
     driz.add_image(insci, inwcs, inwht=inwht)
-    
+
     if ok:
         driz.write(output_template)
     else:
         driz.write(output)
         template_data = read_image(output_template)
-        
+
         (min_diff, med_diff, max_diff) = centroid_statistics("turbo with grid", output_difference,
                                                                   driz.outsci, template_data, 20.0, 8)
 
@@ -311,7 +308,7 @@ def test_gaussian_with_grid():
     output = os.path.join(OUTPUT_DIR, 'output_gaussian_grid.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_gaussian_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_gaussian_grid.fits')
-    
+
     insci = read_image(input_file)
     inwcs = read_wcs(input_file)
     insci = make_grid_image(insci, 64, 100.0)
@@ -320,13 +317,13 @@ def test_gaussian_with_grid():
 
     driz = drizzle.Drizzle(outwcs=output_wcs, wt_scl="", kernel='gaussian')
     driz.add_image(insci, inwcs, inwht=inwht)
-    
+
     if ok:
         driz.write(output_template)
     else:
         driz.write(output)
         template_data = read_image(output_template)
-        
+
         (min_diff, med_diff, max_diff) = centroid_statistics("gaussian with grid", output_difference,
                                                                   driz.outsci, template_data, 20.0, 8)
 
@@ -341,7 +338,7 @@ def test_lanczos_with_grid():
     output = os.path.join(OUTPUT_DIR, 'output_lanczos_grid.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_lanczos_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_lanczos_grid.fits')
-    
+
     insci = read_image(input_file)
     inwcs = read_wcs(input_file)
     insci = make_grid_image(insci, 64, 100.0)
@@ -350,13 +347,13 @@ def test_lanczos_with_grid():
 
     driz = drizzle.Drizzle(outwcs=output_wcs, wt_scl="", kernel='lanczos3')
     driz.add_image(insci, inwcs, inwht=inwht)
-    
+
     if ok:
         driz.write(output_template)
     else:
         driz.write(output)
         template_data = read_image(output_template)
-        
+
         (min_diff, med_diff, max_diff) = centroid_statistics("lanczos with grid", output_difference,
                                                                   driz.outsci, template_data, 20.0, 8)
 
@@ -371,7 +368,7 @@ def test_tophat_with_grid():
     output = os.path.join(OUTPUT_DIR, 'output_tophat_grid.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_tophat_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_tophat_grid.fits')
-    
+
     insci = read_image(input_file)
     inwcs = read_wcs(input_file)
     insci = make_grid_image(insci, 64, 100.0)
@@ -380,13 +377,13 @@ def test_tophat_with_grid():
 
     driz = drizzle.Drizzle(outwcs=output_wcs, wt_scl="", kernel='tophat')
     driz.add_image(insci, inwcs, inwht=inwht)
-    
+
     if ok:
         driz.write(output_template)
     else:
         driz.write(output)
         template_data = read_image(output_template)
-        
+
         (min_diff, med_diff, max_diff) = centroid_statistics("tophat with grid", output_difference,
                                                                   driz.outsci, template_data, 20.0, 8)
 
@@ -401,7 +398,7 @@ def test_point_with_grid():
     output = os.path.join(OUTPUT_DIR, 'output_point_grid.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_point_grid.txt')
     output_template = os.path.join(DATA_DIR, 'reference_point_grid.fits')
-    
+
     insci = read_image(input_file)
     inwcs = read_wcs(input_file)
     insci = make_grid_image(insci, 64, 100.0)
@@ -410,13 +407,13 @@ def test_point_with_grid():
 
     driz = drizzle.Drizzle(outwcs=output_wcs, wt_scl="", kernel='point')
     driz.add_image(insci, inwcs, inwht=inwht)
-    
+
     if ok:
         driz.write(output_template)
     else:
         driz.write(output)
         template_data = read_image(output_template)
-        
+
         (min_diff, med_diff, max_diff) = centroid_statistics("point with grid", output_difference,
                                                                   driz.outsci, template_data, 20.0, 8)
 
@@ -431,7 +428,7 @@ def test_blot_with_point():
     output = os.path.join(OUTPUT_DIR, 'output_blot_point.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_blot_point.txt')
     output_template = os.path.join(DATA_DIR, 'reference_blot_point.fits')
-    
+
     outsci = read_image(input_file)
     outwcs = read_wcs(input_file)
     outsci = make_point_image(outsci, (500, 200), 40.0)
@@ -461,7 +458,7 @@ def test_blot_with_default():
     output = os.path.join(OUTPUT_DIR, 'output_blot_default.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_blot_default.txt')
     output_template = os.path.join(DATA_DIR, 'reference_blot_default.fits')
-    
+
     outsci = read_image(input_file)
     outsci = make_grid_image(outsci, 64, 100.0)
     outwcs = read_wcs(input_file)
@@ -492,7 +489,7 @@ def test_blot_with_lan3():
     output = os.path.join(OUTPUT_DIR, 'output_blot_lan3.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_blot_lan3.txt')
     output_template = os.path.join(DATA_DIR, 'reference_blot_lan3.fits')
-    
+
     outsci = read_image(input_file)
     outsci = make_grid_image(outsci, 64, 100.0)
     outwcs = read_wcs(input_file)
@@ -523,7 +520,7 @@ def test_blot_with_lan5():
     output = os.path.join(OUTPUT_DIR, 'output_blot_lan5.fits')
     output_difference = os.path.join(OUTPUT_DIR, 'difference_blot_lan5.txt')
     output_template = os.path.join(DATA_DIR, 'reference_blot_lan5.fits')
-    
+
     outsci = read_image(input_file)
     outsci = make_grid_image(outsci, 64, 100.0)
     outwcs = read_wcs(input_file)
@@ -553,7 +550,7 @@ if __name__ == "__main__":
     for flag in sys.argv[1:]:
         if flag == 'ok':
             ok = True
-            
+
     test_square_with_point()
     test_square_with_grid()
     test_turbo_with_grid()
@@ -565,4 +562,3 @@ if __name__ == "__main__":
     test_blot_with_default()
     test_blot_with_lan3()
     test_blot_with_lan5()
-    
\ No newline at end of file
