@@ -1,5 +1,3 @@
-from __future__ import division, print_function, unicode_literals, absolute_import
-
 import sys
 import glob
 import math
@@ -14,6 +12,9 @@ import numpy.testing as npt
 from astropy import wcs
 from astropy.io import fits
 
+from drizzle import drizzle
+from drizzle import util
+
 TEST_DIR = os.path.abspath(os.path.dirname(__file__))
 DATA_DIR = os.path.join(TEST_DIR, 'data')
 OUTPUT_DIR = os.environ.get('DRIZZLE_TEST_OUTPUT_DIR', tempfile.mkdtemp())
@@ -24,9 +25,6 @@ def output_dir():
     if 'DRIZZLE_TEST_OUTPUT_DIR' not in os.environ:
         shutil.rmtree(OUTPUT_DIR)
 
-from .. import drizzle
-from .. import util
-
 def read_header(filename):
     """
     Read the primary header from a fits file
